@@ -9,6 +9,7 @@ import (
 	"testing"
 
 	"github.com/influxdata/telegraf/plugins/parsers"
+	"github.com/influxdata/telegraf/plugins/parsers/csv"
 	"github.com/influxdata/telegraf/testutil"
 )
 
@@ -35,13 +36,12 @@ func TestCSVGZImport(t *testing.T) {
 	err = r.Init()
 	require.NoError(t, err)
 
-	parserConfig := parsers.Config{
-		DataFormat:        "csv",
-		CSVHeaderRowCount: 1,
-	}
-	require.NoError(t, err)
 	r.SetParserFunc(func() (parsers.Parser, error) {
-		return parsers.NewParser(&parserConfig)
+		parser := csv.Parser{
+			HeaderRowCount: 1,
+		}
+		err := parser.Init()
+		return &parser, err
 	})
 	r.Log = testutil.Logger{}
 
@@ -215,15 +215,14 @@ func TestCSVNoSkipRows(t *testing.T) {
 	err = r.Init()
 	require.NoError(t, err)
 
-	parserConfig := parsers.Config{
-		DataFormat:        "csv",
-		CSVHeaderRowCount: 1,
-		CSVSkipRows:       0,
-		CSVTagColumns:     []string{"line1"},
-	}
-	require.NoError(t, err)
 	r.SetParserFunc(func() (parsers.Parser, error) {
-		return parsers.NewParser(&parserConfig)
+		parser := csv.Parser{
+			HeaderRowCount: 1,
+			SkipRows:       0,
+			TagColumns:     []string{"line1"},
+		}
+		err := parser.Init()
+		return &parser, err
 	})
 	r.Log = testutil.Logger{}
 
@@ -288,15 +287,14 @@ func TestCSVSkipRows(t *testing.T) {
 	err = r.Init()
 	require.NoError(t, err)
 
-	parserConfig := parsers.Config{
-		DataFormat:        "csv",
-		CSVHeaderRowCount: 1,
-		CSVSkipRows:       2,
-		CSVTagColumns:     []string{"line1"},
-	}
-	require.NoError(t, err)
 	r.SetParserFunc(func() (parsers.Parser, error) {
-		return parsers.NewParser(&parserConfig)
+		parser := csv.Parser{
+			HeaderRowCount: 1,
+			SkipRows:       2,
+			TagColumns:     []string{"line1"},
+		}
+		err := parser.Init()
+		return &parser, err
 	})
 	r.Log = testutil.Logger{}
 
@@ -363,14 +361,13 @@ func TestCSVMultiHeader(t *testing.T) {
 	err = r.Init()
 	require.NoError(t, err)
 
-	parserConfig := parsers.Config{
-		DataFormat:        "csv",
-		CSVHeaderRowCount: 2,
-		CSVTagColumns:     []string{"line1"},
-	}
-	require.NoError(t, err)
 	r.SetParserFunc(func() (parsers.Parser, error) {
-		return parsers.NewParser(&parserConfig)
+		parser := csv.Parser{
+			HeaderRowCount: 2,
+			TagColumns:     []string{"line1"},
+		}
+		err := parser.Init()
+		return &parser, err
 	})
 	r.Log = testutil.Logger{}
 
