@@ -5,17 +5,20 @@ import (
 	"context"
 	"crypto/tls"
 	"encoding/json"
+	"errors"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net"
 	"net/http"
 	"time"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
 	tlsint "github.com/influxdata/telegraf/plugins/common/tls"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/parsers/influx"
+	"github.com/influxdata/telegraf/plugins/parsers/influx/influx_upstream"
 	"github.com/influxdata/telegraf/selfstat"
 )
 
@@ -25,6 +28,8 @@ const (
 	defaultMaxBodySize = 32 * 1024 * 1024
 )
 
+var ErrEOF = errors.New("EOF")
+
 // The BadRequestCode constants keep standard error messages
 // see: https://v2.docs.influxdata.com/v2.0/api/#operation/PostWrite
 type BadRequestCode string
@@ -39,9 +44,10 @@ type InfluxDBV2Listener struct {
 	port           int
 	tlsint.ServerConfig
 
-	MaxBodySize internal.Size `toml:"max_body_size"`
-	Token       string        `toml:"token"`
-	BucketTag   string        `toml:"bucket_tag"`
+	MaxBodySize config.Size `toml:"max_body_size"`
+	Token       string      `toml:"token"`
+	BucketTag   string      `toml:"bucket_tag"`
+	ParserType  string      `toml:"parser_type"`
 
 	timeFunc influx.TimeFunc
 
@@ -91,6 +97,11 @@ const sampleConfig = `
   ## Optional token to accept for HTTP authentication.
   ## You probably want to make sure you have TLS configured above for this.
   # token = "some-long-shared-secret-token"
+
+  ## Influx line protocol parser
+  ## 'internal' is the default. 'upstream' is a newer parser that is faster
+  ## and more memory efficient.
+  # parser_type = "internal"
 `
 
 func (h *InfluxDBV2Listener) SampleConfig() string {
@@ -134,8 +145,8 @@ func (h *InfluxDBV2Listener) Init() error {
 	h.authFailures = selfstat.Register("influxdb_v2_listener", "auth_failures", tags)
 	h.routes()
 
-	if h.MaxBodySize.Size == 0 {
-		h.MaxBodySize.Size = defaultMaxBodySize
+	if h.MaxBodySize == 0 {
+		h.MaxBodySize = config.Size(defaultMaxBodySize)
 	}
 
 	return nil
@@ -210,7 +221,9 @@ func (h *InfluxDBV2Listener) handleReady() http.HandlerFunc {
 			"started": h.startTime.Format(time.RFC3339Nano),
 			"status":  "ready",
 			"up":      h.timeFunc().Sub(h.startTime).String()})
-		res.Write(b)
+		if _, err := res.Write(b); err != nil {
+			h.Log.Debugf("error writing in handle-ready: %v", err)
+		}
 	}
 }
 
@@ -225,22 +238,26 @@ func (h *InfluxDBV2Listener) handleWrite() http.HandlerFunc {
 	return func(res http.ResponseWriter, req *http.Request) {
 		defer h.writesServed.Incr(1)
 		// Check that the content length is not too large for us to handle.
-		if req.ContentLength > h.MaxBodySize.Size {
-			tooLarge(res, h.MaxBodySize.Size)
+		if req.ContentLength > int64(h.MaxBodySize) {
+			if err := tooLarge(res, int64(h.MaxBodySize)); err != nil {
+				h.Log.Debugf("error in too-large: %v", err)
+			}
 			return
 		}
 
 		bucket := req.URL.Query().Get("bucket")
 
 		body := req.Body
-		body = http.MaxBytesReader(res, body, h.MaxBodySize.Size)
+		body = http.MaxBytesReader(res, body, int64(h.MaxBodySize))
 		// Handle gzip request bodies
 		if req.Header.Get("Content-Encoding") == "gzip" {
 			var err error
 			body, err = gzip.NewReader(body)
 			if err != nil {
 				h.Log.Debugf("Error decompressing request body: %v", err.Error())
-				badRequest(res, Invalid, err.Error())
+				if err := badRequest(res, Invalid, err.Error()); err != nil {
+					h.Log.Debugf("error in bad-request: %v", err)
+				}
 				return
 			}
 			defer body.Close()
@@ -249,30 +266,47 @@ func (h *InfluxDBV2Listener) handleWrite() http.HandlerFunc {
 		var readErr error
 		var bytes []byte
 		//body = http.MaxBytesReader(res, req.Body, 1000000) //p.MaxBodySize.Size)
-		bytes, readErr = ioutil.ReadAll(body)
+		bytes, readErr = io.ReadAll(body)
 		if readErr != nil {
 			h.Log.Debugf("Error parsing the request body: %v", readErr.Error())
-			badRequest(res, InternalError, readErr.Error())
+			if err := badRequest(res, InternalError, readErr.Error()); err != nil {
+				h.Log.Debugf("error in bad-request: %v", err)
+			}
 			return
 		}
-		metricHandler := influx.NewMetricHandler()
-		parser := influx.NewParser(metricHandler)
-		parser.SetTimeFunc(h.timeFunc)
 
 		precisionStr := req.URL.Query().Get("precision")
-		if precisionStr != "" {
-			precision := getPrecisionMultiplier(precisionStr)
-			metricHandler.SetTimePrecision(precision)
-		}
 
 		var metrics []telegraf.Metric
 		var err error
+		if h.ParserType == "upstream" {
+			parser := influx_upstream.NewParser()
+			parser.SetTimeFunc(influx_upstream.TimeFunc(h.timeFunc))
 
-		metrics, err = parser.Parse(bytes)
+			if precisionStr != "" {
+				precision := getPrecisionMultiplier(precisionStr)
+				parser.SetTimePrecision(precision)
+			}
 
-		if err != influx.EOF && err != nil {
+			metrics, err = parser.Parse(bytes)
+		} else {
+			metricHandler := influx.NewMetricHandler()
+			parser := influx.NewParser(metricHandler)
+			parser.SetTimeFunc(h.timeFunc)
+
+			if precisionStr != "" {
+				precision := getPrecisionMultiplier(precisionStr)
+				metricHandler.SetTimePrecision(precision)
+			}
+
+			metrics, err = parser.Parse(bytes)
+		}
+
+		if err != ErrEOF && err != nil {
 			h.Log.Debugf("Error parsing the request body: %v", err.Error())
-			badRequest(res, Invalid, err.Error())
+			if err := badRequest(res, Invalid, err.Error()); err != nil {
+				h.Log.Debugf("error in bad-request: %v", err)
+			}
 			return
 		}
 
@@ -290,7 +324,7 @@ func (h *InfluxDBV2Listener) handleWrite() http.HandlerFunc {
 	}
 }
 
-func tooLarge(res http.ResponseWriter, maxLength int64) {
+func tooLarge(res http.ResponseWriter, maxLength int64) error {
 	res.Header().Set("Content-Type", "application/json")
 	res.Header().Set("X-Influxdb-Error", "http: request body too large")
 	res.WriteHeader(http.StatusRequestEntityTooLarge)
@@ -298,10 +332,11 @@ func tooLarge(res http.ResponseWriter, maxLength int64) {
 		"code":      fmt.Sprint(Invalid),
 		"message":   "http: request body too large",
 		"maxLength": fmt.Sprint(maxLength)})
-	res.Write(b)
+	_, err := res.Write(b)
+	return err
 }
 
-func badRequest(res http.ResponseWriter, code BadRequestCode, errString string) {
+func badRequest(res http.ResponseWriter, code BadRequestCode, errString string) error {
 	res.Header().Set("Content-Type", "application/json")
 	if errString == "" {
 		errString = "http: bad request"
@@ -314,7 +349,8 @@ func badRequest(res http.ResponseWriter, code BadRequestCode, errString string)
 		"op":      "",
 		"err":     errString,
 	})
-	res.Write(b)
+	_, err := res.Write(b)
+	return err
 }
 
 func getPrecisionMultiplier(precision string) time.Duration {
