@@ -6,7 +6,7 @@ import (
 	"net/http/httptest"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/testutil"
@@ -80,7 +80,7 @@ func TestJolokia2_ScalarValues(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "scalar_without_attribute", map[string]interface{}{
 		"value": 123.0,
@@ -240,7 +240,7 @@ func TestJolokia2_ObjectValues(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "object_without_attribute", map[string]interface{}{
 		"biz": 123.0,
@@ -328,7 +328,7 @@ func TestJolokia2_StatusCodes(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "ok", map[string]interface{}{
 		"value": 1.0,
@@ -378,7 +378,7 @@ func TestJolokia2_TagRenaming(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "default_tag_prefix", map[string]interface{}{
 		"value": 123.0,
@@ -471,7 +471,7 @@ func TestJolokia2_FieldRenaming(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "default_field_modifiers", map[string]interface{}{
 		"DEFAULT_PREFIX_hello_DEFAULT_SEPARATOR_world": 123.0,
@@ -579,7 +579,7 @@ func TestJolokia2_MetricMbeanMatching(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "mbean_name_and_object_keys", map[string]interface{}{
 		"value": 123.0,
@@ -672,7 +672,7 @@ func TestJolokia2_MetricCompaction(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "compact_metric", map[string]interface{}{
 		"value": 123.0,
@@ -733,7 +733,7 @@ func TestJolokia2_ProxyTargets(t *testing.T) {
 	plugin := setupPlugin(t, fmt.Sprintf(config, server.URL))
 
 	var acc testutil.Accumulator
-	assert.NoError(t, plugin.Gather(&acc))
+	require.NoError(t, plugin.Gather(&acc))
 
 	acc.AssertContainsTaggedFields(t, "hello", map[string]interface{}{
 		"value": 123.0,
@@ -755,11 +755,11 @@ func TestFillFields(t *testing.T) {
 
 	results := map[string]interface{}{}
 	newPointBuilder(Metric{Name: "test", Mbean: "complex"}, []string{"this", "that"}, "/").fillFields("", complexPoint, results)
-	assert.Equal(t, map[string]interface{}{}, results)
+	require.Equal(t, map[string]interface{}{}, results)
 
 	results = map[string]interface{}{}
 	newPointBuilder(Metric{Name: "test", Mbean: "scalar"}, []string{"this", "that"}, "/").fillFields("", scalarPoint, results)
-	assert.Equal(t, map[string]interface{}{}, results)
+	require.Equal(t, map[string]interface{}{}, results)
 }
 
 func setupServer(resp string) *httptest.Server {
