@@ -37,6 +37,9 @@ type AzureDataExplorer struct {
 const (
 	tablePerMetric = "tablepermetric"
 	singleTable    = "singletable"
+	// These control the amount of memory we use when ingesting blobs
+	bufferSize = 1 << 20 // 1 MiB
+	maxBuffers = 5
 )
 
 type localIngestor interface {
@@ -238,7 +241,7 @@ func (adx *AzureDataExplorer) Init() error {
 		return errors.New("Metrics grouping type is not valid")
 	}
 
-	serializer, err := json.NewSerializer(time.Second, "") // FIXME: get the json.TimestampFormat from the config file
+	serializer, err := json.NewSerializer(time.Nanosecond, time.RFC3339Nano)
 	if err != nil {
 		return err
 	}
@@ -256,7 +259,7 @@ func init() {
 }
 
 func createRealIngestor(client localClient, database string, tableName string) (localIngestor, error) {
-	ingestor, err := ingest.New(client.(*kusto.Client), database, tableName)
+	ingestor, err := ingest.New(client.(*kusto.Client), database, tableName, ingest.WithStaticBuffer(bufferSize, maxBuffers))
 	if ingestor != nil {
 		return ingestor, nil
 	}
