@@ -7,7 +7,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/gogo/protobuf/proto"
 	"github.com/golang/snappy"
 	"github.com/prometheus/common/model"
 	"github.com/prometheus/prometheus/prompb"
@@ -664,7 +663,7 @@ func prompbToText(data []byte) ([]byte, error) {
 		return nil, err
 	}
 	var req prompb.WriteRequest
-	err = proto.Unmarshal(protobuff, &req)
+	err = req.Unmarshal(protobuff)
 	if err != nil {
 		return nil, err
 	}
